# MachinePolicyResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**space_id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**is_default** | **bool** |  | [optional] 
**machine_health_check_policy** | [**MachineHealthCheckPolicy**](MachineHealthCheckPolicy.md) |  | [optional] 
**machine_connectivity_policy** | [**MachineConnectivityPolicy**](MachineConnectivityPolicy.md) |  | [optional] 
**machine_cleanup_policy** | [**MachineCleanupPolicy**](MachineCleanupPolicy.md) |  | [optional] 
**machine_update_policy** | [**MachineUpdatePolicy**](MachineUpdatePolicy.md) |  | [optional] 
**polling_request_queue_timeout** | **str** |  | [optional] 
**polling_request_maximum_message_processing_timeout** | **str** |  | [optional] 
**connection_retry_sleep_interval** | **str** |  | [optional] 
**connection_retry_count_limit** | **int** |  | [optional] 
**connection_retry_time_limit** | **str** |  | [optional] 
**connection_connect_timeout** | **str** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


